Braintree class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

requestApplePayNonce(String authorization, BraintreeApplePayRequest request, {bool collectDeviceData = false}) Future<BraintreePaymentMethodNonce?>
Presents the native Apple Pay sheet and requests a payment method nonce.
requestPaypalNonce(String authorization, BraintreePayPalRequest request, {bool collectDeviceData = false}) Future<BraintreePaymentMethodNonce?>
Requests a PayPal payment method nonce.
showCreditCardForm(BuildContext context, {required String authorization, required String amount}) Future<BraintreePaymentMethodNonce?>
tokenizeCreditCard(String authorization, BraintreeCreditCardRequest request, {bool collectDeviceData = false, bool requestThreeDSecureVerification = false, BraintreeBillingAddress? billingAddress, String? email}) Future<BraintreePaymentMethodNonce?>
Tokenizes a credit card.