BraintreePayPalRequest class
Properties
-
amount
↔ String?
-
Amount of the transaction. If amount is
null, PayPal will use the billing agreement (Vault) flow.
If amount is set, PayPal will follow the one time payment (Checkout) flow.
getter/setter pair
-
appLinkReturnUrl
↔ String?
-
Android only. The HTTPS App Link URL used to return to the app after the
PayPal web flow (Braintree Android v5). Recommended for production: the
domain must be registered in the Braintree Control Panel, hosted with an
assetlinks.json, and declared as an App Link intent-filter on
FlutterBraintreeCustom.
getter/setter pair
-
billingAgreementDescription
↔ String?
-
Description for the billing agreement for the Vault flow.
getter/setter pair
-
currencyCode
↔ String?
-
Currency code. If set to
null, PayPal will choose it based on the active merchant account in the client token.
getter/setter pair
-
displayName
↔ String?
-
The merchant name displayed in the PayPal flow. If set to
null, PayPal will use the company name in your Braintree account.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
payPalPaymentIntent
↔ PayPalPaymentIntent
-
The payment intent in the PayPal Checkout flow.
getter/setter pair
-
payPalPaymentUserAction
↔ PayPalPaymentUserAction
-
The user action in the PayPal Checkout flow. See PayPalPaymentUserAction
for additional documentation.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Converts this request object into a JSON-encodable format.
-
toString()
→ String
-
A string representation of this object.
inherited