displayName property
The merchant name displayed in the PayPal flow. If set to null, PayPal will use the company name in your Braintree account.
Implementation
String? displayName;
The merchant name displayed in the PayPal flow. If set to null, PayPal will use the company name in your Braintree account.
String? displayName;