deviceData property
Device data string for fraud prevention, populated when collectDeviceData
was requested. null otherwise.
Implementation
final String? deviceData;
Device data string for fraud prevention, populated when collectDeviceData
was requested. null otherwise.
final String? deviceData;